<?php

/**
 * JCH Optimize - Aggregate and minify external resources for optmized downloads
 * 
 * @author Samuel Marshall <sdmarshall73@gmail.com>
 * @copyright Copyright (c) 2010 Samuel Marshall
 * @license GNU/GPLv3, See LICENSE file
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

class CodeAlfa_JchOptimize_Block_Form_Multiselect extends Mage_Adminhtml_Block_System_Config_Form_Field
{

        protected function _getElementHtml(Varien_Data_Form_Element_Abstract $element)
        {
                $element->addClass('inputbox chzn-custom-value input-xlarge');
                $attributes = 'data-custom_group_text="Custom Position" data-no_results_text="Add custom item"';

                $select = str_replace('<select', '<select ' . $attributes, $element->getElementHtml());
                
                return $select;
        }

        public function render(Varien_Data_Form_Element_Abstract $element)
        {
                $id = $element->getHtmlId();

                $html = '<td class="label"><label for="' . $id . '">' . $element->getLabel() . '</label></td>';

                //$isDefault = !$this->getRequest()->getParam('website') && !$this->getRequest()->getParam('store');
                $isMultiple = $element->getExtType() === 'multiple';

                // replace [value] with [inherit]
                $namePrefix = preg_replace('#\[value\](\[\])?$#', '', $element->getName());

                $options = $element->getValues();

                $addInheritCheckbox = false;
                if ($element->getCanUseWebsiteValue())
                {
                        $addInheritCheckbox = true;
                        $checkboxLabel      = $this->__('Use Website');
                }
                elseif ($element->getCanUseDefaultValue())
                {
                        $addInheritCheckbox = true;
                        $checkboxLabel      = $this->__('Use Default');
                }

                if ($addInheritCheckbox)
                {
                        $inherit = $element->getInherit() == 1 ? 'checked="checked"' : '';
                        if ($inherit)
                        {
                                $element->setDisabled(true);
                        }
                }

                if ($element->getTooltip())
                {
                        $html .= '<td class="value with-tooltip">';
                        $html .= $this->_getElementHtml($element);
                        $html .= '<div class="field-tooltip"><div>' . $element->getTooltip() . '</div></div>';
                }
                else
                {
                        $html .= '<td class="value">';
                        $html .= $this->_getElementHtml($element);
                };
                if ($element->getComment())
                {
                        $html.= '<p class="note"><span>' . $element->getComment() . '</span></p>';
                }
                $html.= '</td>';

                if ($addInheritCheckbox)
                {

                        $defText = $element->getDefaultValue();
                        if ($options)
                        {
                                $defTextArr = array();
                                foreach ($options as $k => $v)
                                {
                                        if ($isMultiple)
                                        {
                                                if (is_array($v['value']) && in_array($k, $v['value']))
                                                {
                                                        $defTextArr[] = $v['label'];
                                                }
                                        }
                                        elseif (isset($v['value']))
                                        {
                                                if ($v['value'] == $defText)
                                                {
                                                        $defTextArr[] = $v['label'];
                                                        break;
                                                }
                                        }
                                        elseif (!is_array($v))
                                        {
                                                if ($k == $defText)
                                                {
                                                        $defTextArr[] = $v;
                                                        break;
                                                }
                                        }
                                }
                                $defText = join(', ', $defTextArr);
                        }

                        // default value
                        $html.= '<td class="use-default">';
                        $html.= '<input id="' . $id . '_inherit" name="'
                                . $namePrefix . '[inherit]" type="checkbox" value="1" class="checkbox config-inherit" '
                                . $inherit . ' onclick="toggleValueElements(this, Element.previous(this.parentNode))" /> ';
                        $html.= '<label for="' . $id . '_inherit" class="inherit" title="'
                                . htmlspecialchars($defText) . '">' . $checkboxLabel . '</label>';
                        $html.= '</td>';
                }
                
                $html.= '<td class="">';

                $button = sprintf('<button type="button" style="margin-top: 10px;" onclick="addJchOption(\'%s\')">Add item</button>', $element->getId());
                $html .= $button;
                
                $html.= '</td>';
                
                $html.= '<td class="scope-label">';
                if ($element->getScope())
                {
                        $html .= $element->getScopeLabel();
                }
                $html.= '</td>';

                

                return $this->_decorateRowHtml($element, $html);
        }

}
