<?php

/**
 * JCH Optimize - Aggregate and minify external resources for optmized downloads
 * 
 * @author Samuel Marshall <sdmarshall73@gmail.com>
 * @copyright Copyright (c) 2010 Samuel Marshall
 * @license GNU/GPLv3, See LICENSE file
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

class JchPlatformCache implements JchInterfaceCache
{
        /**
         * 
         * @param type $id
         * @param type $lifetime
         * @return type
         */
        public static function getCache($id, $checkexpire=false)
        {
                $cache = Mage::app()->getCache();
                
                $content = $cache->load($id, !$checkexpire);
                
                if(!empty($content))
                {
                        $content = unserialize(base64_decode($content));
                }
                
                return $content;
        }

        /**
         * 
         * @param type $id
         * @param type $lifetime
         * @param type $function
         * @param type $args
         * @return type
         */
        public static function getCallbackCache($id, $function, $args)
        {
                $content = self::getCache($id, true);

                if ($content === FALSE)
                {
                        $content = call_user_func_array($function, $args);
                        
			self::saveCache($content, $id);
                }

                return $content;
        }

        public static function gc()
        {
		$cache = Mage::app()->getCache();
		$cache->clean('old');
		self::cleanStaticCache(true);
        }

	public static function saveCache($content, $id)
	{
		$cache = Mage::app()->getCache();
		$cache->save(base64_encode(serialize($content)), $id, array('jch_optimize_cache'), 86400);
	}

	public static function deleteCache()
	{
		$cache = Mage::app()->getCache();
		$cache->clean();
		self::cleanStaticCache();
	}

	private static function cleanStaticCache($expiredonly = false)
	{
                $obj = new Varien_Io_File();
		$obj->cd(JchPlatformPaths::cachePath());

		$files = $obj->ls();

		foreach ($files as $file)
		{
			if($expiredonly)
			{
				if (time() > strtotime($file['mod_date']) + 86400)
				{
					$obj->rm($file['id']);
				}
			}
			else
			{
				$obj->rm($file['id']);
			}
		}
	}
}
